/**
 * ApplicationState
 *
 * The ApplicationState are all of the bits of data required by multiple objects - MXML components,
 * services, etc. that are active during the life of the application.
 *
 * The ApplicationState should be used as a singleton and accessed as:
 *		ApplicationState.instance
 *
 */
package com.adobe.actors
{
	import mx.collections.ArrayCollection;
    import mx.collections.IViewCursor;
	import flash.events.Event;
	import flash.events.EventDispatcher;
	import mx.events.FlexEvent;
	
	[Bindable]
	public class ApplicationState extends EventDispatcher
	{
		/**
		 * constructor
		 */
		public function ApplicationState()
		{
			// set the endDate to be 'today'
			endDate = new Date();
			endDate.hours = 23;
			endDate.minutes = 59;
			endDate.seconds = 59;
			// modify the startDate
			startDate = new Date( endDate.time - 180*24*60*60*1000 );
			startDate.hours = 0;
			startDate.minutes = 0;
			startDate.seconds = 0;
		}
		
		/**
		 * singleton private instance.
		 */
		private static var self:ApplicationState = new ApplicationState();
		
		/**
		 * instance
		 * 
		 * Returns the singleton instance.
		 */
		public static function get instance() : ApplicationState
		{
			return self;
		}
		
		/* Dates used to search for tickets
		 */
		public var startDate:Date = null; // will be set to endDate - 180 days in constructor
		public var endDate:Date = new Date(); // ie, today
		
		/* List of Products
		 */
		
		public var productList:Array;
		
		/* List of Languages Supported
		 */
		
		public var languageList:Array;
		
		/* List of possible Engineers
		 */
		 
		private var _listOfEngineers:ArrayCollection;
		
		[Bindable(event="engineersChanged")]
		public function set listOfEngineers( ac:ArrayCollection ) : void
		{
			_listOfEngineers = ac;
			
			var dummyEngineer:Engineer = new Engineer();
			dummyEngineer.id = 0;
			dummyEngineer.name = "Select";
			dummyEngineer.email = "";
			
			_listOfEngineers.addItemAt(dummyEngineer, 0 );
			dispatchEvent( new FlexEvent("engineersChanged") );
		}
		public function get listOfEngineers() : ArrayCollection
		{
			return _listOfEngineers;
		}
		
		/* Logged-in or Selected Engineer */
		
		private var _engineer:Engineer;
		
		[Bindable(event="engineerChanged")]
		public function set engineer( e:Engineer ) : void
		{
			_engineer = e;
			dispatchEvent( new FlexEvent("engineerChanged") );
		}
		public function get engineer() : Engineer
		{
			return _engineer;
		}
		
		/* Customer List for this engineer */
		 
		private var _customerList:ArrayCollection;
			
		[Bindable(event="customerListChanged")]
		public function set customerList( ac:ArrayCollection ) : void
		{
			_customerList = ac;
			dispatchEvent( new FlexEvent("customerListChanged") );
		}
		public function get customerList() : ArrayCollection
		{
			return _customerList;
		}
		
		/* Tickets for this engineer */
		 
		private var _tickets:ArrayCollection;
		
		[Bindable(event="ticketsChanged")]
		public function set tickets( ac:ArrayCollection ) : void
		{
			_tickets = ac;
			dispatchEvent( new FlexEvent("ticketsChanged") );
		}
		public function get tickets() : ArrayCollection
		{
			return _tickets;
		}
		
		/* Added By PhilFlash */
		public function getEngineerForId(id:Number):Engineer	
		{
			if (_listOfEngineers == null) return null;
	    	var cursor:IViewCursor = _listOfEngineers.createCursor();
	   		while (!cursor.afterLast)
	    	{
	    		var engineer:Engineer = cursor.current as Engineer;
	    		if (engineer.id == id) return engineer;
				cursor.moveNext();
			}	
			return null;
		}
		
		public function getCustomerForId(id:Number):Customer	
		{
			if (_customerList == null) return null;
	    	var cursor:IViewCursor = _customerList.createCursor();
	   		while (!cursor.afterLast)
	    	{
	    		var customer:Customer = cursor.current as Customer;
	    		if (customer.id == id) return customer;
				cursor.moveNext();
			}	
			return null;
		}
		
	}
}